\\ Copyright 2016, 2017 Kevin Ryde
\\
\\ This file is free software; you can redistribute it and/or modify it
\\ under the terms of the GNU General Public License as published by the Free
\\ Software Foundation; either version 3, or (at your option) any later
\\ version.
\\
\\ This file is distributed in the hope that it will be useful, but
\\ WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
\\ or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
\\ for more details.
\\
\\ You should have received a copy of the GNU General Public License along
\\ with this file.  See the file COPYING.  If not, see
\\ <http://www.gnu.org/licenses/>.

default(recover,0);
read("terdragon-defines.gp");

check_count = 0;
check_exact(got,want,name="") =
{
  check_count++;
  if(got!= want,
     print("wrong "name);
     print("got  "got);
     print("want "want);
     quit(1),
     print("ok "check_count" "name));
}

\\-----------------------------------------------------------------------------

E6 = 1/24;
E2  =   1/216;
E8  =   1/8;
E4  =   1/72;
E10 =   3/8;
emax = vecmax([E2,E8, E4,E10, E6]);

N2  =      1/58320;
N4  =      1/6480;
N8  =      1/80;
N10 =      9/80;

seg_initial = [0,1, 0,1];

\\         t1   t2
\\        /  \ /  \
\\ zs    m1---m2   ze
\\   \  / \  /
\\    b1   b2
\\
seg_expand(seg) =
{
  my(fs=seg[1], fe=seg[2], zs=seg[3], ze=seg[4],
     df=(fe-fs)/9,
     dz=(ze-zs)/3,
     m1=zs+dz, m2=zs+2*dz,
     t1 = m1+dz*w6, t2 = m2+dz*w6,
     b1 = m1-dz*w6, b2 = m2-dz*w6);
  [ [ fs,        fs +   df,  zs,b1 ],
   [  fs +   df, fs + 2*df,  b1,m1 ],
   [  fs + 2*df, fs + 3*df,  m1,b2 ],
   [  fs + 3*df, fs + 4*df,  b2,m2 ],
   [  fs + 4*df, fs + 5*df,  m2,m1 ],
   [  fs + 5*df, fs + 6*df,  m1,t1 ],
   [  fs + 6*df, fs + 7*df,  t1,m2 ],
   [  fs + 7*df, fs + 8*df,  m2,t2 ],
   [  fs + 8*df, fe,         t2,ze ] ];
}
seg_expand(seg_initial)

seg_is_centreline(seg) =
{
  my(fs=seg[1], fe=seg[2], zs=seg[3], ze=seg[4]);
  imag(zs)==0 || imag(ze)==0;
}
check_exact(seg_is_centreline(seg_initial), 1);

vec_range(v) = [vecmin(v),vecmax(v)];

seg_to_x_range(seg) =
{
  my(fs=seg[1], fe=seg[2], zs=seg[3], ze=seg[4],
     dz=ze-zs,
     zlen=geom_abs(dz),v);


  \\ \\ 3/8 each way
  \\ return(vec_range([real(zs) + zlen*emax,
  \\                   real(zs) - zlen*emax,
  \\                   real(ze) + zlen*emax,
  \\                   real(ze) - zlen*emax]));

  \\ \\ 1/2 each way -- k>=31 is 7
  \\ \\ before that 1111...111 candidate too
  \\ my(f);
  \\ f=1/2;
  \\ f=1;
  \\ return(vec_range([real(zs) + zlen*f,
  \\                   real(zs) - zlen*f,
  \\                   real(ze) + zlen*f,
  \\                   real(ze) - zlen*f]));

  \\ hull vertices -- k>=30 is 3, disproving 111...111

  if(imag(zs)==0 && imag(ze)==0,
     return(vec_range([real(zs) + zlen*E6,
                       real(zs) - zlen*E6,
                       real(ze) + zlen*E6,
                       real(ze) - zlen*E6])));

  if(imag(zs)==0, ,
     imag(ze)==0, my(t=zs); zs=ze; ze=t,
     return([]));

  \\         ze
  \\        /
  \\ E4---zs-----E10
  if(imag(ze)>0 && real(ze)>real(zs),
     return(vec_range([real(zs) - zlen*E4,
                       real(zs) + zlen*E10])));
  
  \\    ze
  \\      \
  \\ E2----zs----E8
  if(imag(ze)>0 && real(ze)<real(zs),
     return(vec_range([real(zs) - zlen*E2,
                       real(zs) + zlen*E8])));

  \\ E8----zs-----E2
  \\         \
  \\          ze
  if(imag(ze)<0 && real(ze)>real(zs),
     return(vec_range([real(zs) - zlen*E8,
                       real(zs) + zlen*E2])));

  \\ E10----zs----E4
  \\       /
  \\     ze
  if(imag(ze)<0 && real(ze)<real(zs),
     return(vec_range([real(zs) - zlen*E10,
                       real(zs) + zlen*E4])));

  return([]);
}
\\check_exact(seg_to_x_range(seg_initial), [-1/24, 1+1/24]);

seg_to_f_range(seg) =
{
  my(fs=seg[1], fe=seg[2], zs=seg[3], ze=seg[4],
     df=fe-fs);

  \\ whole range
  \\ k=27  #seglist=9
  \\   frange [0.2097241738807431438503323417, 0.7902758261192568561496676584]
  \\ k=28  #seglist=7
  \\   frange [0.2097241738807447628289155460, 0.7902758261192552371710844540]
  \\ k=29  #seglist=5
  \\   frange [0.2097241738807447628289155480, 0.7902758261192552371710844521]
  \\ k=30  #seglist=3
  \\   frange [0.5000000000000000000000000000, 0.5000000000000000000000000000]
  \\return([fs,fe]);

  if(imag(zs)==0 && imag(ze)==0,
     return([fs,fe]));

  if(imag(zs)==0, ,
     imag(ze)==0, my(t=zs);zs=ze;ze=t; t=fs;fs=fe;fe=t; df=-df,
     return([]));

  \\         ze
  \\        /
  \\ E4---zs-----E10
  if(imag(ze)>0 && real(ze)>real(zs),
     return(vec_range([fs,
                       fs + df*N10])));
  
  \\    ze
  \\      \
  \\ E2----zs----E8
  if(imag(ze)>0 && real(ze)<real(zs),
     return(vec_range([fs,
                       fs + df*N8])));

  \\ E8----zs-----E2
  \\         \
  \\          ze
  if(imag(ze)<0 && real(ze)>real(zs),
     return(vec_range([fs,
                       fs + df*N2])));

  \\ E10----zs----E4
  \\       /
  \\     ze
  if(imag(ze)<0 && real(ze)<real(zs),
     return(vec_range([fs,
                       fs + df*N4])));

  return([]);
}
\\check_exact(seg_to_x_range(seg_initial), [-1/24, 1+1/24]);

seg_is_within_f(seg) =
{
  my(fs=seg[1], fe=seg[2], zs=seg[3], ze=seg[4],
     [f1,f2]=seg_to_f_range(seg),
     [x1,x2]=seg_to_x_range(seg));
  x1 <= f2 && x2 >= f1;
}
check_exact(seg_is_within_f(seg_initial), 1);

seg_validate(seg) =
{
  my(fs=seg[1], fe=seg[2], zs=seg[3], ze=seg[4]);
  terdragon_fpoint(fs)==zs || error();
  terdragon_fpoint(fe)==ze || error();
}
check_exact(seg_is_within_f(seg_initial), 1);

seglist_to_f_range(v) =
{
  v=Vec(v);
  [ vecmin(apply(seg->seg[1],v)),
   vecmax(apply(seg->seg[2],v)) ];
}
seg_reverse(seg) =
{
  my(fs=seg[1], fe=seg[2], zs=seg[3], ze=seg[4]);
  [ 1-fe, 1-fs, 1-ze, 1-zs ];
}
check_exact(seg_reverse(seg_initial), seg_initial);

seglist_reverse(v) = Vecrev(apply(seg_reverse,v));

segs_print(v) =
{
  for(i=1,#v,
     my(seg=v[i]*81);
     print(" "seg
           "    "seg_to_x_range(seg)
           "  ",seg_is_centreline(seg)&&seg_is_within_f(seg)));
}

print("initial exp");
segs_print(seg_expand(seg_initial));
\\quit

print();
print("1-2");
segs_print(seg_expand([1/9, 2/9, 1/6 - 1/6*sqrt3i, 1/3]));
[117/8, 171/8]*1.0
171/8-117/8
geom_abs(1/6 - 1/6*sqrt3i - 1/3)

print("7-8");
segs_print(seg_expand([7/9, 8/9, 2/3, 5/6 + 1/6*sqrt3i]));
[465/8, 507/8]*1.0
507/8-465/8
geom_abs(2/3 -( 5/6 + 1/6*sqrt3i))
\\ quit

\\ [f, zs, ze]
k=0;
seglist = [ seg_initial ];
{
  my(verbose=1);
  for(reps=1,36,
     print("k="k"  #seglist="#seglist);
     print("  frange ",1.0*seglist_to_f_range(seglist[min(2,#seglist)
                                                  .. #seglist-1]));
     my(revs=seglist_reverse(seglist));
     if(revs!=seglist,
        print("not symmetric");
        print("segs");segs_print(seglist*81);
        print("revs");segs_print(revs*81);
        quit);

     my(new_seglist=List([]));
     for(i=1,#seglist,
        if(verbose,print(" seg "seglist[i]*9^k)); \\ 
        seg_validate(seglist[i]);
        my(v=seg_expand(seglist[i]));
        for(j=1,#v,
           my(seg=v[j], c=seg_is_centreline(seg), w=c&&seg_is_within_f(seg));
           if(verbose>=2, print(" consider "seg"  "c " "w));
           if(w, listput(new_seglist,seg))));
     seglist = Vec(new_seglist);
     k++);
}
quit
     if(verbose && reps<10,
        print1("  ");
        for(i=1,#fs,
           print1(fs[i]/flen);
           while(i<#fs && fs[i+1]==flen+fs[i], i++);
           print1("--"fs[i]/flen",  "));
        print());

     if(verbose,
        my(runs=0);
        for(i=1,#fs,
           runs++;
           while(i<#fs && fs[i+1]==flen+fs[i], i++));
        print("  runs ",runs,"  mean ",#fs/runs*1.0);
       );

     my(new_fs=List([]), skip=0);
     flen/=3;
     zlen/=sqrt3;
     my(zlimit=3*zlen);
     for(i=1,#fs,
        my(f=fs[i]);
        for(step=0,2,
           my(z=terdragon_fpoint(f));
           if(abs(geom_point_y(z)  ) > zlimit, skip++; next());
           if(abs(geom_point_x(z)-f) > zlimit, skip++; next());
           listput(new_fs,f);
           f+=flen);
     );
     fs=new_fs;
     if(verbose, print("  skip ",skip));
  );
}
{
  for(i=1,#fs,
     my(z=terdragon_fpoint(fs[i]));
     print(fs[i]*1.0);
     print(" n="decimal_to_ternary(fs[i]*3^k));
     print(" x="decimal_to_ternary(floor(geom_point_x(z)*3^ceil(k/2))));
  );
}

\\ #"111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111"
\\ #"1111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111111"


\\ 0.8163604766596108788302178783
\\ cf Kempner-Mahler
\\ 0.816421509021893143708079
\\ 0.0000610    differs at bit 2^-15, and sum those bits for 2^-14
\\ printf("%f",2.0^-14)
\\ 36+6==42