#!/usr/bin/perl -w

# Copyright 2015, 2016, 2018 Kevin Ryde
#
# This file is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 3, or (at your option) any later
# version.
#
# This file is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
# You should have received a copy of the GNU General Public License along
# with this file.  If not, see <http://www.gnu.org/licenses/>.

use 5.004;
use strict;
use FindBin;
use Math::PlanePath::TerdragonCurve 117; # v.117 for level_to_n_range()

use FindBin;
BEGIN { unshift @INC, $FindBin::Bin }
use lib::abs "$FindBin::Bin/../tools";
use MyTerdragon ':all';
use MyLineSegments;
use MyPrintwrap ':all';

# uncomment this to run the ### lines
# use Smart::Comments;

my $level = 11;   # of the sub-parts

my $ex = 2;
my $ey = 0;
my $points_R = [
                [0,0],
                [$ex,$ey],
               ];
my $points_V = [
                [0,0],
                [1,1],
                [$ex,$ey],
               ];

my (@points_R_array, @points_V_array);

foreach my $k (1 .. $level) {
  push @points_R_array, $points_R;
  push @points_V_array, $points_V;
  ($points_R,$points_V,$ex,$ey) = hull_expand_RV($points_R,$points_V,$ex,$ey);
}

sub coord {
  my ($x,$y) = @_;
  $x /= 100;
  $y /= 100;
  return "$x,{$y*sqrt(3)}";
}

{
  $Printwrap = 2;
  printwrap("% generated by tools/$FindBin::Script\n");
  printwrap("\\draw ");
  my $join = '';
  $Printwrap += 2;
  foreach my $i (0 .. $#$points_R) {
    my $p = $points_R->[$i];
    my ($x,$y) = @$p;
    my $xy = coord($x,$y);
    my $num = $i+1;
    printwrap("$join($xy) node[my dot,name=PR${num}A]\n");
    $join = '--';
  }
  printwrap("--cycle;\n");

  $Printwrap = 2;
  printwrap("\\draw ");
  $join = '';
  $Printwrap += 2;
  foreach my $i (0 .. $#$points_V) {
    my $p = $points_V->[$i];
    my ($x,$y) = @$p;
    ($x,$y) = xy_rotate_plus60($x,$y);
    $x += $ex;
    $y += $ey;
    my $xy = coord($x,$y);
    my $num = $i+1;
    printwrap("$join($xy) node[my dot,name=PV${num}B]\n");
    $join = '--';
  }
  printwrap("--cycle;\n");

  {
    my $xy = coord($ex,$ey);
    print "  \\coordinate (middle) at ($xy);\n";
  }
  {
    my $xy = coord(mul($ex,$ey));
    print "  \\coordinate (end) at ($xy);\n";
  }
  print "  % end generated\n";
}

{
  $Printwrap = 2;
  printwrap("% generated by tools/$FindBin::Script\n");
  printwrap("\\draw ");
  my $join = '';
  $Printwrap += 2;
  foreach my $i (0 .. $#$points_R) {
    my $p = $points_R->[$i];
    my ($x,$y) = @$p;
    ($x,$y) = xy_rotate_plus60($x,$y);
    my $xy = coord($x,$y);
    my $num = $i+1;
    printwrap("$join($xy) node[my dot,name=PR${num}A]\n");
    $join = '--';
  }
  printwrap("--cycle;\n");

  my ($ex60,$ey60) = xy_rotate_plus60($ex,$ey);

  $Printwrap = 2;
  printwrap("\\draw ");
  $join = '';
  $Printwrap += 2;
  foreach my $i (0 .. $#$points_V) {
    my $p = $points_V->[$i];
    my ($x,$y) = @$p;
    $x += $ex60;
    $y += $ey60;
    my $xy = coord($x,$y);
    my $num = $i+1;
    printwrap("$join($xy) node[my dot,name=PV${num}B]\n");
    $join = '--';
  }
  printwrap("--cycle;\n");

  {
    my $xy = coord($ex60,$ey60);
    print "  \\coordinate (middle) at ($xy);\n";
  }
  {
    my $xy = coord(mul($ex,$ey));
    print "  \\coordinate (end) at ($xy);\n";
  }
  print "  % end generated\n";
}

exit 0;
