\\ Copyright 2015, 2017 Kevin Ryde
\\
\\ This file is free software; you can redistribute it and/or modify it
\\ under the terms of the GNU General Public License as published by the Free
\\ Software Foundation; either version 3, or (at your option) any later
\\ version.
\\
\\ This file is distributed in the hope that it will be useful, but
\\ WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
\\ or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
\\ for more details.
\\
\\ You should have received a copy of the GNU General Public License along
\\ with this file.  See the file COPYING.  If not, see
\\ <http://www.gnu.org/licenses/>.


default(recover,0);
read("terdragon-defines.gp");

check_count = 0;
check_exact(got,want,name="") =
{
  check_count++;
  if(got!= want,
     print("wrong "name);
     print("got  "got);
     print("want "want);
     quit(1),
     print("ok "check_count" "name));
}

vector_mean(v) = vecsum(v)/#v;

/* vector_unique(v) returns the unique elements from
   vector v.  Elements are compared with ==.
   The first of each set of equal elements are returned,
   and in the same order as the original. */
vector_unique(v) = \
  my(seen=List([]), result=List([])); \
  for(i=1,#v, \
      my(pos=setsearch(seen,v[i],1)); \
      if(pos, listput(result,v[i]); \
              listinsert(seen,v[i], pos); \
              1,                 /* new */ \
              0));               /* already seen */ \
  Vec(result);

\\-----------------------------------------------------------------------------

mean_radius(k) =
{
  my(G = b^k/2);
  vector_mean(apply(z->abs(z-G),
                   vector_unique
                   (terdragon_points(k))));
}
\\for(k=0,7,print(mean_radius(k)/sqrt(3)^k));

\\-----------------------------------------------------------------------------

\\ line z1 to z2 mean radius  

\\  t=1
\\ int   abs(z1 + (z2-z1)*t)  dt
\\  t=0
\\       = sqrt(real(z1+(z2-z1)*t)^2 + imag(z1+(z2-z1)*t)^2) dt
\\       = sqrt( (Rz1+(Rz2-Rz1)*t)^2 + (Iz1+(Iz2-Iz1)*t)^2 ) dt
\\       = sqrt( A*t^2 + B*t + C ) dt

\\ int sqrt(x^2 + a^2) = x/2*sqrt(x^2+a^2) + a^2*log(abs( x + sqrt(x^2+a^2) ))
\\ if a==0 then
\\ int x = 1/2*x^2
int_sqrt_x2_plus_a2(a, x0,x1) =
{
  if(a==0, return(1/2*x1^2 - 1/2*x0^2));

  my(s0 = sqrt(x0^2 + a^2));
  my(s1 = sqrt(x1^2 + a^2));
  (x1/2*s1 + a^2/2*log(abs(x1 + s1))) - (x0/2*s0 + a^2/2*log(abs(x0 + s0)));
}

\\ (sqrtA*t + 1/2*B/sqrtA)^2 == sqrtA^2*t^2 + B*t + B^2/(4*sqrtA^2)
\\ (t + 1/2*B)^2 == t^2 + B*t + 1/4*B^2

mean_steps = 10000;
line_mean_radius_by_sum(z1,z2) =
{
  sum(t=0,mean_steps, t/=mean_steps; abs(z1+(z2-z1)*t))
   / mean_steps;
}

line_mean_radius_numerically(z1,z2) =
{
  intnum(t=0,1, abs(z1+(z2-z1)*t));
}

\\ polcoeff((Rz1+(Rz2-Rz1)*'t)^2 + (Iz1+(Iz2-Iz1)*'t)^2, 1,'t)/-2
\\ f = sqrt(  (Rz2-Rz1)^2 + (Iz2-Iz1)^2  ) = abs(z1-z2)
\\ norm((Rz1+Iz1*I)-(Rz2+Iz2*I)) + norm((Rz1+Iz1*I)+(Rz2+Iz2*I))

line_mean_radius(z1,z2) =
{
  my(p = real(z1+(z2-z1)*'t)^2 + imag(z1+(z2-z1)*'t)^2);
  print("p ",p);
  my(t_low = 0);
  my(t_high = 1);
  print(" t="t_low" to "t_high" is p=",subst(p,'t,t_low)," to "subst(p,'t,t_high));

  my(f = sqrt(polcoeff(p,2)));
  p /= polcoeff(p,2);
  print(" t="t_low" to "t_high" is p=",subst(p,'t,t_low)," to "subst(p,'t,t_high));

  my(s = 1/2*polcoeff(p,1));
  t_low += s;
  t_high += s;
  p = subst(p, 't, 't - s);
  print(" t="t_low" to "t_high" is p=",subst(p,'t,t_low)," to "subst(p,'t,t_high),"  of ",p);
  \\ return(f * intnum(t=t_low,t_high, sqrt(subst(p,'t,t))));

  if(polcoeff(p,0) < 0, error());
  my(a = sqrt_as_quad(polcoeff(p,0)));
  print(" t^2 + a^2 with a=",a);
  \\ return(f * intnum(t=t_low,t_high, sqrt_as_quad(t^2+a^2)));

  f * int_sqrt_x2_plus_a2(a, t_low,t_high);
}
print("by sum      ", line_mean_radius_by_sum(3*I,6)*1.0);
print("numerically ", line_mean_radius_numerically(3*I,6));
print("by expr     ", line_mean_radius(3*I,6));




\\-----------------------------------------------------------------------------

polygon_boundary(v) = \
  sum(i=1,#v, abs(vector_modulo(v,i) - vector_modulo(v,i+1)));

polygon_mean_radius(v) =
{
  my(total_radius = 0, total_length = 0);
  for(i=1,#v,
        my(z1 = vector_modulo(v,i),
           z2 = vector_modulo(v,i+1),
           l = abs(z1-z2));
        total_radius += line_mean_radius(z1,z2)*l;
        total_length += l);
  print("total_radius ", total_radius);
  print("total_length ", total_length);
  total_radius / total_length;
}

print("hull mean radius ", polygon_mean_radius(hull_limit_centred))
\\ mean_steps = 100;
\\ print("mean radius ", polygon_mean_radius(hull_limit))




\\ p=2 to 5  of t^2 + 1  a=1
\\ 1/2*log(5)-1/2*log(2)
\\ 2/2*sqrt(2+1) + 1*log(abs( 2 + sqrt(2+1) ))
\\ 1/2*sqrt(1+1) + 1*log(abs( 1 + sqrt(1+1) ))
\\ log(2+sqrt(3))       \\ = A065918
\\ log(2+sqrt(3)) - log(1+sqrt(2))
\\ log( (2+sqrt(3))/(1+sqrt(2)) )

\\-----------------------------------------------------------------------------

line_min_radius(z1,z2) =
{
  my(m=1e1000);
  for(t=0,mean_steps, my(t=t/mean_steps); m=min(m, abs(z1+(z2-z1)*t)));
  m;
}
min_side = -1;
polygon_min_radius(v) =
{
  my(m = 1e1000, side=-1);
  for(i=1,#v,
        my(z1 = vector_modulo(v,i),
           z2 = vector_modulo(v,i+1));
     my(r = line_min_radius(z1,z2));
     if(r < m,
        m = r;
        min_side = i));
  m;
}
print("max radius ", vecmax(apply(abs,hull_limit_centred)));
print("min radius ", polygon_min_radius(hull_limit_centred));
print("min side  P", min_side+1, "--P",  min_side+2);
