#!/usr/bin/perl -w

# Copyright 2019 Kevin Ryde
#
# This file is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 3, or (at your option) any later
# version.
#
# This file is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
# You should have received a copy of the GNU General Public License along
# with this file.  If not, see <http://www.gnu.org/licenses/>.

use 5.004;
use strict;
use FindBin;
use List::Util 'sum';
use Math::PlanePath::TerdragonCurve 117; # v.117 for level_to_n_range()

BEGIN { unshift @INC, $FindBin::Bin }
use MyTerdragon 'RpointPred','xy_to_node_name';
use MyLineSegments;
use MyPrintwrap ':all';


my $level = 4;
print "  % generated by tools/$FindBin::Script\n";
print "  \\newcommand{\\MyLevel}{$level}\n";

my $path = Math::PlanePath::TerdragonCurve->new;
my ($n_lo, $n_hi) = $path->level_to_n_range($level);
my ($x_hi,$y_hi) = $path->n_to_xy($n_hi);

my %RpointPred_nodes;
$Printwrap = 2;
foreach my $n ($n_lo .. $n_hi) {
  next unless RpointPred($n);
  my ($x,$y) = $path->n_to_xy($n);
  unless (exists $RpointPred_nodes{"$x,$y"}) {
    my $name = ($n==0 ? 'start'
                : $n==$n_hi ? 'end'
                : xy_to_node_name($x,$y));
    printwrap(" \\node ($name) at ($x,$y) [my dot];");
    $RpointPred_nodes{"$x,$y"} = "($name)";
  }
}

my $segments = MyLineSegments->new;
foreach my $n ($n_lo .. $n_hi - 1) {
  $segments->add($path->n_to_xy($n),
                 $path->n_to_xy($n+1));
}
$Printwrap = 2;
printwrap("\\draw[my line] ");
$Printwrap = 4;
$segments->printwrap (stringize => sub {
                        my ($x,$y) = @_;
                        return $RpointPred_nodes{"$x,$y"};
                      });
printwrap(";\n");

print "  % end generated\n";
exit 0;
