#!/usr/bin/perl -w

# Copyright 2019 Kevin Ryde
#
# This file is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 3, or (at your option) any later
# version.
#
# This file is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
# You should have received a copy of the GNU General Public License along
# with this file.  If not, see <http://www.gnu.org/licenses/>.

use 5.004;
use strict;
use Math::PlanePath::TerdragonCurve 117; # v.117 for level_to_n_range()

use FindBin;
use lib $FindBin::Bin;
use MyTerdragon 'transform_to_horizontal';
use MyLineSegments;
use MyPrintwrap ':all';


my $level = 6;
if (@ARGV) { $level = shift @ARGV; }

print "  % generated by tools/$FindBin::Script $level\n";
print "  \\newcommand{\\MyLevel}{$level}\n";

my $path = Math::PlanePath::TerdragonCurve->new;
my ($n_lo, $n_hi) = $path->level_to_n_range($level);

sub transform {
  my ($x,$y) = @_;
  ($x,$y) = transform_to_horizontal($x,$y, $level);
  return ($x, $y);
}

my $centreline_segments = MyLineSegments->new;
my $other_segments = MyLineSegments->new;
my $CentrelineSegments = 0;
my $CentrelineVisits = 0;
my $CentrelineH = 0;
my %CentrelineP;
foreach my $n ($n_lo .. $n_hi-1) {
  my ($x1,$y1) = $path->n_to_xy($n);
  my ($x2,$y2) = $path->n_to_xy($n+1);
  my ($tx1,$ty1) = transform($x1,$y1);
  my ($tx2,$ty2) = transform($x2,$y2);
  if ($ty1*$ty2 <= 0) {   # zero or opposite signs
    $centreline_segments->add($x1,$y1, $x2,$y2);
    $CentrelineSegments++;
  } else {
    $other_segments->add($x1,$y1, $x2,$y2);
  }
  if ($ty1==0 && $ty2==0) {
    $CentrelineH++;
  }
  if ($ty1==0) {
    $CentrelineVisits++;
  }
  if ($ty1==0) { $CentrelineP{$tx1} = 1; }
  if ($ty2==0) { $CentrelineP{$tx2} = 1; }
}
{
  my ($x,$y) = transform($path->n_to_xy($n_hi));
  $y==0 || die "oops";
  $CentrelineVisits++;
  $CentrelineP{$x} = 1;
}
my $CentrelineP = scalar keys %CentrelineP;

$Printwrap = 2;
printwrap("\\draw[my other] ");
$Printwrap = 4;
$other_segments->printwrap (transform => \&transform);
printwrap(";\n");

$Printwrap = 2;
printwrap("\\draw[my centreline] ");
$Printwrap = 4;
$centreline_segments->printwrap (transform => \&transform);
printwrap(";\n");

print "  \\node (start) at (0,0) [my dot];\n";
{
  my ($x,$y) = transform($path->n_to_xy($n_hi));
  print "  \\node (end) at ($x,$y) [my dot];\n";
}

print "  \\newcommand{\\MyCentrelineSegments}{$CentrelineSegments}\n";
print "  \\newcommand{\\MyCentrelineP}{$CentrelineP}\n";
print "% GP-Test-Last  CentrelineSegments($level) == $CentrelineSegments\n";
print "% GP-Test-Last  CentrelineVisits($level) == $CentrelineVisits\n";
print "% GP-Test-Last  CentrelineH($level) == $CentrelineH\n";
print "% GP-Test-Last  CentrelineP($level) == $CentrelineP\n";
print "  % end generated\n";
