#!/usr/bin/perl -w

# Copyright 2014, 2015, 2016, 2017, 2018 Kevin Ryde
#
# This file is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 3, or (at your option) any later
# version.
#
# This file is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
# You should have received a copy of the GNU General Public License along
# with this file.  If not, see <http://www.gnu.org/licenses/>.


use 5.004;
use strict;
use FindBin;
use Math::PlanePath::TerdragonCurve 117; # v.117 for level_to_n_range()

BEGIN { unshift @INC, $FindBin::Bin }
use MyTerdragon 'xy_rotate_plus60','xy_rotate_plus120',
  'xy_rotate_minus60','xy_rotate_minus90','xy_rotate_minus120',
  'hull_and_end';
use MyLineSegments;
use MyPrintwrap ':all';


my $level = 8;   # of the sub-parts
print "  % generated by tools/$FindBin::Script\n";

my $path = Math::PlanePath::TerdragonCurve->new;
my ($n_lo, $n_hi) = $path->level_to_n_range($level);
my ($x_hi,$y_hi) = $path->n_to_xy($n_hi);

sub transform {
  my ($x,$y) = @_;
  my $l = $level + 1;
  if ($l % 2 == 1) {
    while ($l > 3) {
      ($x,$y) = xy_rotate_minus60($x,$y);
      $l -= 2;
    }
    ($x,$y) = xy_rotate_minus90($x,$y);
    $l -= 3;
  } else {
    while ($l > 0) {
      ($x,$y) = xy_rotate_minus60($x,$y);
      $l -= 2;
    }
  }
  return ($x,$y);
}

# after transform, these for k=9 whole, k=8 sub-parts
sub in_range {
  my ($x,$y) = @_;
  return ($x >= 36 && $x <= 70
          && $y >= -13 && $y <= 55);
}

my $segments = MyLineSegments->new;
foreach my $n ($n_lo .. 3*$n_hi-1) {
  my ($x1,$y1) = $path->n_to_xy($n);
  my ($x2,$y2) = $path->n_to_xy($n+1);
  if (in_range(transform($x1,$y1)) && in_range(transform($x2,$y2))) {
    $segments->add($x1,$y1, $x2,$y2);
  }
}

# {
#   print "  \\node (start) at (0,0) [my dot];\n";
#   my ($x,$y) = $path->n_to_xy(3*$n_hi);
#   ($x,$y) = transform($x,$y);
#   print "  \\node (end) at ($x,$y) [my dot];\n";
# }

my ($points,$ex,$ey) = hull_and_end($level);
$ex == $x_hi or die;
$ey == $y_hi or die;
my ($x_hi_60,$y_hi_60) = xy_rotate_plus60($x_hi,$y_hi);

my $B_points = [map{ my($x,$y) = @$_;
                     ($x,$y) = xy_rotate_plus120($x,$y);
                     $x += $x_hi;
                     $y += $y_hi;
                     [$x,$y]
                   } @$points];
# } elsif ($part eq 'C') {
#   $x += $x_hi_60;
#   $y += $y_hi_60;

# don't draw segments which will be overlapped by the hull sides
foreach my $points ($points,$B_points) {
  foreach my $i (0 .. $#$points) {
    my ($x1,$y1) = @{$points->[$i-1]};
    my ($x2,$y2) = @{$points->[$i]};
    eval {
      $segments->remove($x1,$y1, $x2,$y2);
      # print "hull side remove i=$i\n";
    };
  }
}

$Printwrap = 2;
printwrap("\\draw[my line] ");
$Printwrap = 4;
$segments->printwrap(transform => \&transform);
printwrap(";\n");

$Printwrap = 2;
foreach my $elem (['A',$points],
                  ['B',$B_points]) {
  my ($name,$points) = @$elem;
  my $num = 1;
  my $dash = '';
  foreach my $p (@$points) {
    my ($x,$y) = @$p;
    ($x,$y) = transform($x,$y);
    printwrap(" \\coordinate (P$num$name$dash) at ($x,$y);");
    $num++;
    if ($num == 8) {
      $num = 1;
      $dash = '-dash';
    }
  }
  printwrap_newline();
}

# {
#   $Printwrap = 2;
#   printwrap("\\draw[my hull] ");
#   $Printwrap += 2;
#   foreach my $part ('A','B','C') {
#     my $num = 1;
#     my $dash = '';
#     my $join = '';
#     foreach (1 .. 14) {
#       printwrap("$join(P$num$part$dash.center)");
#       $num++;
#       if ($num == 8) {
#         $num = 1;
#         $dash = '-dash';
#       }
#       $join = '--';
#     }
#     printwrap("--cycle");
#     if ($part ne 'C') { printwrap("  "); }
#   }
#   printwrap(";\n");
# }


print "  % end generated\n";
exit 0;
