#!/usr/bin/perl -w

# Copyright 2019, 2020 Kevin Hyde
#
# This file is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 3, or (at your option) any later
# version.
#
# This file is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
# You should have received a copy of the GNU General Public License along
# with this file.  If not, see <http://www.gnu.org/licenses/>.

use 5.004;
use strict;
use FindBin;
use List::Util 'max';

use lib $FindBin::Bin;
use MyTerdragon 'dir';
use MyPrintwrap ':all';

my $level = 5;

print "  % generated by tools/$FindBin::Script\n";

sub num_digits {
  my ($n) = @_;
  my $k = 0;
  while ($n) { $k++; $n = int($n/3); }
  return $k;
}
num_digits(8) == 2 or die;
num_digits(9) == 3 or die;

sub num_digits_to_low {
  my ($k) = @_;
  return 3**($k-1);
}
CHECK {
  num_digits(num_digits_to_low(3)-1) == 2 or die;
  num_digits(num_digits_to_low(3))   == 3 or die;
}

sub num_digits_to_range {
  my ($k) = @_;
  return 2*3**($k-1);
}
CHECK {
  num_digits_to_range(3) == num_digits_to_low(4) - num_digits_to_low(3) or die;
}

sub n_to_x {
  my ($n) = @_;
  if ($n==0) { return 0; }
  my $k = num_digits($n);
  my $low = num_digits_to_low($k);
  my $range = num_digits_to_range($k);
  my $r = $n - $low;
  return ($r ? "$k+$r/$range" : $k);
}
CHECK {
  n_to_x(0) == 0 or die;
  n_to_x(1) == 1 or die;
  n_to_x(3) == 2 or die;
  n_to_x(9) == 3 or die;

  dir(0) == 0 or die;
  dir(1) == 1 or die;
  dir(2) == 0 or die;
}

# plot line
my $y_max = 0;
my $prev_y = dir(0);
$Printwrap = 2;
printwrap("\\draw (0,$prev_y)");
$Printwrap += 2;
my $n_hi = 3**$level-1;
foreach my $n (1 .. $n_hi) {
  my $y = dir($n);
  my $x = n_to_x($n);
  printwrap("--($x,$prev_y)");
  printwrap("--($x,$y)");
  $prev_y = $y;
  $y_max = max($y,$y_max);
}
my $x_max = n_to_x($n_hi+1);
printwrap("--($x_max,$prev_y);\n");

print "  \\coordinate (x-max) at ($x_max,0);\n";
print "  \\coordinate (y-max) at (0,$y_max);\n";

# X ticks
$Printwrap = 2;
printwrap("\\draw (0,0)");
$Printwrap += 2;
foreach my $k (-1 .. $level) {
  my $n = ($k<0 ? 0 : 3**$k);
  my $x = n_to_x($n);
  my $semi = ($k==$level ? ";\n" : "");
  printwrap(" ($x,0) -- +(x-tick)$semi");
}

# X numbers
print "  \\begin{scope}[font=\\scriptsize]\n";
foreach my $k (-1 .. $level-1) {
  my $n = ($k<0 ? 0 : 3**$k);
  my $x = n_to_x($n);
  print "  \\node at ($x,0) [below right,my x number] {\$$n\$};\n";
}

# Y ticks and numbers
$Printwrap = 2;
printwrap("\\draw");
$Printwrap += 2;
foreach my $y (1 .. $y_max) {
  my $semi = ($y==$y_max ? ";\n" : "");
  printwrap(" (0,$y) -- +(y-tick) node[at start,left] {\$$y\$}$semi");
}
print "  \\end{scope}\n";

print "  % end generated\n";
exit 0;
