#!/usr/bin/perl -w

# Copyright 2014 Kevin Ryde
#
# This file is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 3, or (at your option) any later
# version.
#
# This file is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
# You should have received a copy of the GNU General Public License along
# with this file.  If not, see <http://www.gnu.org/licenses/>.

use 5.004;
use strict;
use FindBin;
use Math::BaseCnv 'cnv';
use Math::PlanePath::TerdragonCurve;

use FindBin;
BEGIN { unshift @INC, $FindBin::Bin }
use MyTerdragon ':all';
use MyLineSegments;
use MyPrintwrap ':all';

# uncomment this to run the ### lines
# use Smart::Comments;


my $level = 4;
print "  % generated by tools/$FindBin::Script\n";

my $power = 3**$level;
print "  % level=$level power=$power\n";

{
  my $path = Math::PlanePath::TerdragonCurve->new;
  my $segments = MyLineSegments->new;
  foreach my $n (0 .. $power-1) {
    if ($path->_UNDOCUMENTED__n_segment_is_right_boundary(3*$n)) {
      $segments->add($n,0, $n+1,0);
    }
  }
  $Printwrap = 2;
  printwrap("\\draw");
  $Printwrap = 4;
  foreach my $line ($segments->lines) {
    my ($x1,$y1, $x2,$y2) = @$line;
    printwrap(" ($x1,$y1)--($x2,$y2)");
  }
  printwrap(";\n");
}

sub is_cantor {
  my ($n) = @_;
  my $n3 = Math::BaseCnv::cnv($n,10,3);
  return ($n3 !~ /1/);
}

{
  my $path = Math::PlanePath::TerdragonCurve->new;
  my $segments = MyLineSegments->new;
  foreach my $n (0 .. $power-1) {
    if (is_cantor($n)) {
      $segments->add($n,0, $n+1,0);
    }
  }

  $Printwrap = 2;
  printwrap("\\begin{scope}[shift=(below-pos)]\n");
  $Printwrap = 4;
  printwrap("\\draw");
  $Printwrap = 6;
  foreach my $line ($segments->lines) {
    my ($x1,$y1, $x2,$y2) = @$line;
    printwrap(" ($x1,$y1)--($x2,$y2)");
  }
  printwrap(";\n");
  $Printwrap = 2;
  printwrap("\\end{scope}\n");
}

print "  % end generated\n";
exit 0;
