#!/usr/bin/perl -w

# Copyright 2014, 2018 Kevin Ryde
#
# This file is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 3, or (at your option) any later
# version.
#
# This file is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
# You should have received a copy of the GNU General Public License along
# with this file.  If not, see <http://www.gnu.org/licenses/>.


use 5.004;
use strict;
use Math::PlanePath::R5DragonCurve;

use FindBin;
use lib::abs $FindBin::Bin;
use MyTerdragon;
use MyPrintwrap ':all';

# uncomment this to run the ### lines
# use Smart::Comments;


my $width = 20;
my $height = 9;
printwrap("  % generated by tools/$FindBin::Script\n");

sub in_range {
  my ($x,$y) = @_;
  return ($x >= 0 && $x <= $width
          && $y >= 1 && $y <= $height);
}

my @circles;
sub draw {
  my ($x1,$y1, $x2,$y2) = @_;
  my $x = ($x2 + $x1)/2;
  my $y = ($y2 + $y1)/2;
  my $dy = ($y2 - $y1)/2;
  if (in_range($x1,$y1)) {
    if ($dy) {
      $x1 += 1;
      $y1 += $dy;
    } else {
      $x1 += 2;
    }
  }
  if (in_range($x2,$y2)) {
    if ($dy) {
      $x2 -= 1;
      $y2 -= $dy;
    } else {
      $x2 -= 2;
    }
  }
  if ($x1 != $x2) {
    printwrap " ($x1,{$y1*sqrt(3)})--($x2,{$y2*sqrt(3)})";
  }
}

$Printwrap = 2;
printwrap("\\draw\n");
$Printwrap += 2;
foreach my $y (1 .. $height) {

  # lower horizontal
  {
    my $x = ($y&1);
    if ($x && in_range($x,$y-1)) {
      printwrap("(0,{$y*sqrt(3)-.5})--");
    }
    printwrap("($x,{$y*sqrt(3)})");
    for ( ; $x <= $width; $x+=2) {
      push @circles, "($x,{$y*sqrt(3)})circle";

      my $x2 = $x+2;
      my $xm = $x+1;
      my $y2 = $y;
      if (in_range($x2,$y2) || in_range($xm,$y2-1)) {
        printwrap("--($xm,{$y*sqrt(3)-.5})");
      }
      if (in_range($x2,$y2)) {
        printwrap("--($x2,{$y2*sqrt(3)})");
      }
    }
  }

  # upper horizontal
  {
    my $x = ($y&1);
    if ($x && in_range($x,$y+1)) {
      printwrap("(0,{$y*sqrt(3)+.5})--");
    }
    printwrap("($x,{$y*sqrt(3)})");
    for ( ; $x <= $width; $x+=2) {

      my $x2 = $x+2;
      my $xm = $x+1;
      my $y2 = $y;
      if (in_range($x2,$y2) || in_range($xm,$y2+1)) {
        printwrap("--($xm,{$y*sqrt(3)+.5})");
      }
      if (in_range($x2,$y2)) {
        printwrap("--($x2,{$y2*sqrt(3)})");
      }
    }
  }

  # vertical
  {
    for (my $x = ($y&1); $x <= $width; $x+=2) {
      my $y1 = $y - 1;
      if (in_range($x,$y1)) {
        $y1 = "{$y1*sqrt(3)+.5}";
      } else {
        $y1 = "{$y*sqrt(3)}";
      }
      my $y2 = $y + 1;
      if (in_range($x,$y2)) {
        $y2 = "{$y2*sqrt(3)-.5}";
      } else {
        $y2 = "{$y*sqrt(3)}";
      }
      printwrap("($x,$y1)--($x,$y2)\n");
    }
  }
}
printwrap(";\n");

printwrap_indent(" ");
foreach my $circle (@circles) {
  printwrap(" \\filldraw $circle;");
}
printwrap_newline();

printwrap_indent("  ");
printwrap("% end generated\n");
exit 0;







# \begin{center}
# \begin{tikzpicture}[scale=.25,yscale=.95,
#                     every circle/.style={radius=.15,fill},
#                     line cap=round,
#                     thin,
#                    ]
# 
#   % generated by tools/gen-tiling.pl
#   \draw
#    (1,{1*sqrt(3)})--(2,{1*sqrt(3)-.5})--(3,{1*sqrt(3)})--(4,{1*sqrt(3)-.5})
#    --(5,{1*sqrt(3)})--(6,{1*sqrt(3)-.5})--(7,{1*sqrt(3)})--(8,{1*sqrt(3)-.5})
#    --(9,{1*sqrt(3)})--(10,{1*sqrt(3)-.5})--(11,{1*sqrt(3)})
#    --(12,{1*sqrt(3)-.5})--(13,{1*sqrt(3)})--(14,{1*sqrt(3)-.5})
#    --(15,{1*sqrt(3)})--(16,{1*sqrt(3)-.5})--(17,{1*sqrt(3)})
#    --(18,{1*sqrt(3)-.5})--(19,{1*sqrt(3)})(0,{1*sqrt(3)+.5})--(1,{1*sqrt(3)})
#    --(2,{1*sqrt(3)+.5})--(3,{1*sqrt(3)})--(4,{1*sqrt(3)+.5})--(5,{1*sqrt(3)})
#    --(6,{1*sqrt(3)+.5})--(7,{1*sqrt(3)})--(8,{1*sqrt(3)+.5})--(9,{1*sqrt(3)})
#    --(10,{1*sqrt(3)+.5})--(11,{1*sqrt(3)})--(12,{1*sqrt(3)+.5})
#    --(13,{1*sqrt(3)})--(14,{1*sqrt(3)+.5})--(15,{1*sqrt(3)})
#    --(16,{1*sqrt(3)+.5})--(17,{1*sqrt(3)})--(18,{1*sqrt(3)+.5})
#    --(19,{1*sqrt(3)})--(20,{1*sqrt(3)+.5})(1,{1*sqrt(3)})--(1,{2*sqrt(3)-.5})
#    (3,{1*sqrt(3)})--(3,{2*sqrt(3)-.5})
#    (5,{1*sqrt(3)})--(5,{2*sqrt(3)-.5})
#    (7,{1*sqrt(3)})--(7,{2*sqrt(3)-.5})
#    (9,{1*sqrt(3)})--(9,{2*sqrt(3)-.5})
#    (11,{1*sqrt(3)})--(11,{2*sqrt(3)-.5})
#    (13,{1*sqrt(3)})--(13,{2*sqrt(3)-.5})
#    (15,{1*sqrt(3)})--(15,{2*sqrt(3)-.5})
#    (17,{1*sqrt(3)})--(17,{2*sqrt(3)-.5})
#    (19,{1*sqrt(3)})--(19,{2*sqrt(3)-.5})
#    (0,{2*sqrt(3)})--(1,{2*sqrt(3)-.5})--(2,{2*sqrt(3)})--(3,{2*sqrt(3)-.5})
#    --(4,{2*sqrt(3)})--(5,{2*sqrt(3)-.5})--(6,{2*sqrt(3)})--(7,{2*sqrt(3)-.5})
#    --(8,{2*sqrt(3)})--(9,{2*sqrt(3)-.5})--(10,{2*sqrt(3)})--(11,{2*sqrt(3)-.5})
#    --(12,{2*sqrt(3)})--(13,{2*sqrt(3)-.5})--(14,{2*sqrt(3)})
#    --(15,{2*sqrt(3)-.5})--(16,{2*sqrt(3)})--(17,{2*sqrt(3)-.5})
#    --(18,{2*sqrt(3)})--(19,{2*sqrt(3)-.5})--(20,{2*sqrt(3)})(0,{2*sqrt(3)})
#    --(1,{2*sqrt(3)+.5})--(2,{2*sqrt(3)})--(3,{2*sqrt(3)+.5})--(4,{2*sqrt(3)})
#    --(5,{2*sqrt(3)+.5})--(6,{2*sqrt(3)})--(7,{2*sqrt(3)+.5})--(8,{2*sqrt(3)})
#    --(9,{2*sqrt(3)+.5})--(10,{2*sqrt(3)})--(11,{2*sqrt(3)+.5})
#    --(12,{2*sqrt(3)})--(13,{2*sqrt(3)+.5})--(14,{2*sqrt(3)})
#    --(15,{2*sqrt(3)+.5})--(16,{2*sqrt(3)})--(17,{2*sqrt(3)+.5})
#    --(18,{2*sqrt(3)})--(19,{2*sqrt(3)+.5})--(20,{2*sqrt(3)})
#    (0,{1*sqrt(3)+.5})--(0,{3*sqrt(3)-.5})
#    (2,{1*sqrt(3)+.5})--(2,{3*sqrt(3)-.5})
#    (4,{1*sqrt(3)+.5})--(4,{3*sqrt(3)-.5})
#    (6,{1*sqrt(3)+.5})--(6,{3*sqrt(3)-.5})
#    (8,{1*sqrt(3)+.5})--(8,{3*sqrt(3)-.5})
#    (10,{1*sqrt(3)+.5})--(10,{3*sqrt(3)-.5})
#    (12,{1*sqrt(3)+.5})--(12,{3*sqrt(3)-.5})
#    (14,{1*sqrt(3)+.5})--(14,{3*sqrt(3)-.5})
#    (16,{1*sqrt(3)+.5})--(16,{3*sqrt(3)-.5})
#    (18,{1*sqrt(3)+.5})--(18,{3*sqrt(3)-.5})
#    (20,{1*sqrt(3)+.5})--(20,{3*sqrt(3)-.5})
#    (0,{3*sqrt(3)-.5})--(1,{3*sqrt(3)})--(2,{3*sqrt(3)-.5})--(3,{3*sqrt(3)})
#    --(4,{3*sqrt(3)-.5})--(5,{3*sqrt(3)})--(6,{3*sqrt(3)-.5})--(7,{3*sqrt(3)})
#    --(8,{3*sqrt(3)-.5})--(9,{3*sqrt(3)})--(10,{3*sqrt(3)-.5})--(11,{3*sqrt(3)})
#    --(12,{3*sqrt(3)-.5})--(13,{3*sqrt(3)})--(14,{3*sqrt(3)-.5})
#    --(15,{3*sqrt(3)})--(16,{3*sqrt(3)-.5})--(17,{3*sqrt(3)})
#    --(18,{3*sqrt(3)-.5})--(19,{3*sqrt(3)})--(20,{3*sqrt(3)-.5})
#    (0,{3*sqrt(3)+.5})--(1,{3*sqrt(3)})--(2,{3*sqrt(3)+.5})--(3,{3*sqrt(3)})
#    --(4,{3*sqrt(3)+.5})--(5,{3*sqrt(3)})--(6,{3*sqrt(3)+.5})--(7,{3*sqrt(3)})
#    --(8,{3*sqrt(3)+.5})--(9,{3*sqrt(3)})--(10,{3*sqrt(3)+.5})--(11,{3*sqrt(3)})
#    --(12,{3*sqrt(3)+.5})--(13,{3*sqrt(3)})--(14,{3*sqrt(3)+.5})
#    --(15,{3*sqrt(3)})--(16,{3*sqrt(3)+.5})--(17,{3*sqrt(3)})
#    --(18,{3*sqrt(3)+.5})--(19,{3*sqrt(3)})--(20,{3*sqrt(3)+.5})
#    (1,{2*sqrt(3)+.5})--(1,{4*sqrt(3)-.5})
#    (3,{2*sqrt(3)+.5})--(3,{4*sqrt(3)-.5})
#    (5,{2*sqrt(3)+.5})--(5,{4*sqrt(3)-.5})
#    (7,{2*sqrt(3)+.5})--(7,{4*sqrt(3)-.5})
#    (9,{2*sqrt(3)+.5})--(9,{4*sqrt(3)-.5})
#    (11,{2*sqrt(3)+.5})--(11,{4*sqrt(3)-.5})
#    (13,{2*sqrt(3)+.5})--(13,{4*sqrt(3)-.5})
#    (15,{2*sqrt(3)+.5})--(15,{4*sqrt(3)-.5})
#    (17,{2*sqrt(3)+.5})--(17,{4*sqrt(3)-.5})
#    (19,{2*sqrt(3)+.5})--(19,{4*sqrt(3)-.5})
#    (0,{4*sqrt(3)})--(1,{4*sqrt(3)-.5})--(2,{4*sqrt(3)})--(3,{4*sqrt(3)-.5})
#    --(4,{4*sqrt(3)})--(5,{4*sqrt(3)-.5})--(6,{4*sqrt(3)})--(7,{4*sqrt(3)-.5})
#    --(8,{4*sqrt(3)})--(9,{4*sqrt(3)-.5})--(10,{4*sqrt(3)})--(11,{4*sqrt(3)-.5})
#    --(12,{4*sqrt(3)})--(13,{4*sqrt(3)-.5})--(14,{4*sqrt(3)})
#    --(15,{4*sqrt(3)-.5})--(16,{4*sqrt(3)})--(17,{4*sqrt(3)-.5})
#    --(18,{4*sqrt(3)})--(19,{4*sqrt(3)-.5})--(20,{4*sqrt(3)})(0,{4*sqrt(3)})
#    --(1,{4*sqrt(3)+.5})--(2,{4*sqrt(3)})--(3,{4*sqrt(3)+.5})--(4,{4*sqrt(3)})
#    --(5,{4*sqrt(3)+.5})--(6,{4*sqrt(3)})--(7,{4*sqrt(3)+.5})--(8,{4*sqrt(3)})
#    --(9,{4*sqrt(3)+.5})--(10,{4*sqrt(3)})--(11,{4*sqrt(3)+.5})
#    --(12,{4*sqrt(3)})--(13,{4*sqrt(3)+.5})--(14,{4*sqrt(3)})
#    --(15,{4*sqrt(3)+.5})--(16,{4*sqrt(3)})--(17,{4*sqrt(3)+.5})
#    --(18,{4*sqrt(3)})--(19,{4*sqrt(3)+.5})--(20,{4*sqrt(3)})
#    (0,{3*sqrt(3)+.5})--(0,{5*sqrt(3)-.5})
#    (2,{3*sqrt(3)+.5})--(2,{5*sqrt(3)-.5})
#    (4,{3*sqrt(3)+.5})--(4,{5*sqrt(3)-.5})
#    (6,{3*sqrt(3)+.5})--(6,{5*sqrt(3)-.5})
#    (8,{3*sqrt(3)+.5})--(8,{5*sqrt(3)-.5})
#    (10,{3*sqrt(3)+.5})--(10,{5*sqrt(3)-.5})
#    (12,{3*sqrt(3)+.5})--(12,{5*sqrt(3)-.5})
#    (14,{3*sqrt(3)+.5})--(14,{5*sqrt(3)-.5})
#    (16,{3*sqrt(3)+.5})--(16,{5*sqrt(3)-.5})
#    (18,{3*sqrt(3)+.5})--(18,{5*sqrt(3)-.5})
#    (20,{3*sqrt(3)+.5})--(20,{5*sqrt(3)-.5})
#    (0,{5*sqrt(3)-.5})--(1,{5*sqrt(3)})--(2,{5*sqrt(3)-.5})--(3,{5*sqrt(3)})
#    --(4,{5*sqrt(3)-.5})--(5,{5*sqrt(3)})--(6,{5*sqrt(3)-.5})--(7,{5*sqrt(3)})
#    --(8,{5*sqrt(3)-.5})--(9,{5*sqrt(3)})--(10,{5*sqrt(3)-.5})--(11,{5*sqrt(3)})
#    --(12,{5*sqrt(3)-.5})--(13,{5*sqrt(3)})--(14,{5*sqrt(3)-.5})
#    --(15,{5*sqrt(3)})--(16,{5*sqrt(3)-.5})--(17,{5*sqrt(3)})
#    --(18,{5*sqrt(3)-.5})--(19,{5*sqrt(3)})--(20,{5*sqrt(3)-.5})
#    (0,{5*sqrt(3)+.5})--(1,{5*sqrt(3)})--(2,{5*sqrt(3)+.5})--(3,{5*sqrt(3)})
#    --(4,{5*sqrt(3)+.5})--(5,{5*sqrt(3)})--(6,{5*sqrt(3)+.5})--(7,{5*sqrt(3)})
#    --(8,{5*sqrt(3)+.5})--(9,{5*sqrt(3)})--(10,{5*sqrt(3)+.5})--(11,{5*sqrt(3)})
#    --(12,{5*sqrt(3)+.5})--(13,{5*sqrt(3)})--(14,{5*sqrt(3)+.5})
#    --(15,{5*sqrt(3)})--(16,{5*sqrt(3)+.5})--(17,{5*sqrt(3)})
#    --(18,{5*sqrt(3)+.5})--(19,{5*sqrt(3)})--(20,{5*sqrt(3)+.5})
#    (1,{4*sqrt(3)+.5})--(1,{6*sqrt(3)-.5})
#    (3,{4*sqrt(3)+.5})--(3,{6*sqrt(3)-.5})
#    (5,{4*sqrt(3)+.5})--(5,{6*sqrt(3)-.5})
#    (7,{4*sqrt(3)+.5})--(7,{6*sqrt(3)-.5})
#    (9,{4*sqrt(3)+.5})--(9,{6*sqrt(3)-.5})
#    (11,{4*sqrt(3)+.5})--(11,{6*sqrt(3)-.5})
#    (13,{4*sqrt(3)+.5})--(13,{6*sqrt(3)-.5})
#    (15,{4*sqrt(3)+.5})--(15,{6*sqrt(3)-.5})
#    (17,{4*sqrt(3)+.5})--(17,{6*sqrt(3)-.5})
#    (19,{4*sqrt(3)+.5})--(19,{6*sqrt(3)-.5})
#    (0,{6*sqrt(3)})--(1,{6*sqrt(3)-.5})--(2,{6*sqrt(3)})--(3,{6*sqrt(3)-.5})
#    --(4,{6*sqrt(3)})--(5,{6*sqrt(3)-.5})--(6,{6*sqrt(3)})--(7,{6*sqrt(3)-.5})
#    --(8,{6*sqrt(3)})--(9,{6*sqrt(3)-.5})--(10,{6*sqrt(3)})--(11,{6*sqrt(3)-.5})
#    --(12,{6*sqrt(3)})--(13,{6*sqrt(3)-.5})--(14,{6*sqrt(3)})
#    --(15,{6*sqrt(3)-.5})--(16,{6*sqrt(3)})--(17,{6*sqrt(3)-.5})
#    --(18,{6*sqrt(3)})--(19,{6*sqrt(3)-.5})--(20,{6*sqrt(3)})(0,{6*sqrt(3)})
#    --(1,{6*sqrt(3)+.5})--(2,{6*sqrt(3)})--(3,{6*sqrt(3)+.5})--(4,{6*sqrt(3)})
#    --(5,{6*sqrt(3)+.5})--(6,{6*sqrt(3)})--(7,{6*sqrt(3)+.5})--(8,{6*sqrt(3)})
#    --(9,{6*sqrt(3)+.5})--(10,{6*sqrt(3)})--(11,{6*sqrt(3)+.5})
#    --(12,{6*sqrt(3)})--(13,{6*sqrt(3)+.5})--(14,{6*sqrt(3)})
#    --(15,{6*sqrt(3)+.5})--(16,{6*sqrt(3)})--(17,{6*sqrt(3)+.5})
#    --(18,{6*sqrt(3)})--(19,{6*sqrt(3)+.5})--(20,{6*sqrt(3)})
#    (0,{5*sqrt(3)+.5})--(0,{7*sqrt(3)-.5})
#    (2,{5*sqrt(3)+.5})--(2,{7*sqrt(3)-.5})
#    (4,{5*sqrt(3)+.5})--(4,{7*sqrt(3)-.5})
#    (6,{5*sqrt(3)+.5})--(6,{7*sqrt(3)-.5})
#    (8,{5*sqrt(3)+.5})--(8,{7*sqrt(3)-.5})
#    (10,{5*sqrt(3)+.5})--(10,{7*sqrt(3)-.5})
#    (12,{5*sqrt(3)+.5})--(12,{7*sqrt(3)-.5})
#    (14,{5*sqrt(3)+.5})--(14,{7*sqrt(3)-.5})
#    (16,{5*sqrt(3)+.5})--(16,{7*sqrt(3)-.5})
#    (18,{5*sqrt(3)+.5})--(18,{7*sqrt(3)-.5})
#    (20,{5*sqrt(3)+.5})--(20,{7*sqrt(3)-.5})
#    (0,{7*sqrt(3)-.5})--(1,{7*sqrt(3)})--(2,{7*sqrt(3)-.5})--(3,{7*sqrt(3)})
#    --(4,{7*sqrt(3)-.5})--(5,{7*sqrt(3)})--(6,{7*sqrt(3)-.5})--(7,{7*sqrt(3)})
#    --(8,{7*sqrt(3)-.5})--(9,{7*sqrt(3)})--(10,{7*sqrt(3)-.5})--(11,{7*sqrt(3)})
#    --(12,{7*sqrt(3)-.5})--(13,{7*sqrt(3)})--(14,{7*sqrt(3)-.5})
#    --(15,{7*sqrt(3)})--(16,{7*sqrt(3)-.5})--(17,{7*sqrt(3)})
#    --(18,{7*sqrt(3)-.5})--(19,{7*sqrt(3)})--(20,{7*sqrt(3)-.5})
#    (0,{7*sqrt(3)+.5})--(1,{7*sqrt(3)})--(2,{7*sqrt(3)+.5})--(3,{7*sqrt(3)})
#    --(4,{7*sqrt(3)+.5})--(5,{7*sqrt(3)})--(6,{7*sqrt(3)+.5})--(7,{7*sqrt(3)})
#    --(8,{7*sqrt(3)+.5})--(9,{7*sqrt(3)})--(10,{7*sqrt(3)+.5})--(11,{7*sqrt(3)})
#    --(12,{7*sqrt(3)+.5})--(13,{7*sqrt(3)})--(14,{7*sqrt(3)+.5})
#    --(15,{7*sqrt(3)})--(16,{7*sqrt(3)+.5})--(17,{7*sqrt(3)})
#    --(18,{7*sqrt(3)+.5})--(19,{7*sqrt(3)})--(20,{7*sqrt(3)+.5})
#    (1,{6*sqrt(3)+.5})--(1,{8*sqrt(3)-.5})
#    (3,{6*sqrt(3)+.5})--(3,{8*sqrt(3)-.5})
#    (5,{6*sqrt(3)+.5})--(5,{8*sqrt(3)-.5})
#    (7,{6*sqrt(3)+.5})--(7,{8*sqrt(3)-.5})
#    (9,{6*sqrt(3)+.5})--(9,{8*sqrt(3)-.5})
#    (11,{6*sqrt(3)+.5})--(11,{8*sqrt(3)-.5})
#    (13,{6*sqrt(3)+.5})--(13,{8*sqrt(3)-.5})
#    (15,{6*sqrt(3)+.5})--(15,{8*sqrt(3)-.5})
#    (17,{6*sqrt(3)+.5})--(17,{8*sqrt(3)-.5})
#    (19,{6*sqrt(3)+.5})--(19,{8*sqrt(3)-.5})
#    (0,{8*sqrt(3)})--(1,{8*sqrt(3)-.5})--(2,{8*sqrt(3)})--(3,{8*sqrt(3)-.5})
#    --(4,{8*sqrt(3)})--(5,{8*sqrt(3)-.5})--(6,{8*sqrt(3)})--(7,{8*sqrt(3)-.5})
#    --(8,{8*sqrt(3)})--(9,{8*sqrt(3)-.5})--(10,{8*sqrt(3)})--(11,{8*sqrt(3)-.5})
#    --(12,{8*sqrt(3)})--(13,{8*sqrt(3)-.5})--(14,{8*sqrt(3)})
#    --(15,{8*sqrt(3)-.5})--(16,{8*sqrt(3)})--(17,{8*sqrt(3)-.5})
#    --(18,{8*sqrt(3)})--(19,{8*sqrt(3)-.5})--(20,{8*sqrt(3)})(0,{8*sqrt(3)})
#    --(1,{8*sqrt(3)+.5})--(2,{8*sqrt(3)})--(3,{8*sqrt(3)+.5})--(4,{8*sqrt(3)})
#    --(5,{8*sqrt(3)+.5})--(6,{8*sqrt(3)})--(7,{8*sqrt(3)+.5})--(8,{8*sqrt(3)})
#    --(9,{8*sqrt(3)+.5})--(10,{8*sqrt(3)})--(11,{8*sqrt(3)+.5})
#    --(12,{8*sqrt(3)})--(13,{8*sqrt(3)+.5})--(14,{8*sqrt(3)})
#    --(15,{8*sqrt(3)+.5})--(16,{8*sqrt(3)})--(17,{8*sqrt(3)+.5})
#    --(18,{8*sqrt(3)})--(19,{8*sqrt(3)+.5})--(20,{8*sqrt(3)})
#    (0,{7*sqrt(3)+.5})--(0,{9*sqrt(3)-.5})
#    (2,{7*sqrt(3)+.5})--(2,{9*sqrt(3)-.5})
#    (4,{7*sqrt(3)+.5})--(4,{9*sqrt(3)-.5})
#    (6,{7*sqrt(3)+.5})--(6,{9*sqrt(3)-.5})
#    (8,{7*sqrt(3)+.5})--(8,{9*sqrt(3)-.5})
#    (10,{7*sqrt(3)+.5})--(10,{9*sqrt(3)-.5})
#    (12,{7*sqrt(3)+.5})--(12,{9*sqrt(3)-.5})
#    (14,{7*sqrt(3)+.5})--(14,{9*sqrt(3)-.5})
#    (16,{7*sqrt(3)+.5})--(16,{9*sqrt(3)-.5})
#    (18,{7*sqrt(3)+.5})--(18,{9*sqrt(3)-.5})
#    (20,{7*sqrt(3)+.5})--(20,{9*sqrt(3)-.5})
#    (0,{9*sqrt(3)-.5})--(1,{9*sqrt(3)})--(2,{9*sqrt(3)-.5})--(3,{9*sqrt(3)})
#    --(4,{9*sqrt(3)-.5})--(5,{9*sqrt(3)})--(6,{9*sqrt(3)-.5})--(7,{9*sqrt(3)})
#    --(8,{9*sqrt(3)-.5})--(9,{9*sqrt(3)})--(10,{9*sqrt(3)-.5})--(11,{9*sqrt(3)})
#    --(12,{9*sqrt(3)-.5})--(13,{9*sqrt(3)})--(14,{9*sqrt(3)-.5})
#    --(15,{9*sqrt(3)})--(16,{9*sqrt(3)-.5})--(17,{9*sqrt(3)})
#    --(18,{9*sqrt(3)-.5})--(19,{9*sqrt(3)})--(20,{9*sqrt(3)-.5})(1,{9*sqrt(3)})
#    --(2,{9*sqrt(3)+.5})--(3,{9*sqrt(3)})--(4,{9*sqrt(3)+.5})--(5,{9*sqrt(3)})
#    --(6,{9*sqrt(3)+.5})--(7,{9*sqrt(3)})--(8,{9*sqrt(3)+.5})--(9,{9*sqrt(3)})
#    --(10,{9*sqrt(3)+.5})--(11,{9*sqrt(3)})--(12,{9*sqrt(3)+.5})
#    --(13,{9*sqrt(3)})--(14,{9*sqrt(3)+.5})--(15,{9*sqrt(3)})
#    --(16,{9*sqrt(3)+.5})--(17,{9*sqrt(3)})--(18,{9*sqrt(3)+.5})
#    --(19,{9*sqrt(3)})(1,{8*sqrt(3)+.5})--(1,{9*sqrt(3)})
#    (3,{8*sqrt(3)+.5})--(3,{9*sqrt(3)})
#    (5,{8*sqrt(3)+.5})--(5,{9*sqrt(3)})
#    (7,{8*sqrt(3)+.5})--(7,{9*sqrt(3)})
#    (9,{8*sqrt(3)+.5})--(9,{9*sqrt(3)})
#    (11,{8*sqrt(3)+.5})--(11,{9*sqrt(3)})
#    (13,{8*sqrt(3)+.5})--(13,{9*sqrt(3)})
#    (15,{8*sqrt(3)+.5})--(15,{9*sqrt(3)})
#    (17,{8*sqrt(3)+.5})--(17,{9*sqrt(3)})
#    (19,{8*sqrt(3)+.5})--(19,{9*sqrt(3)})
#    ;
#   \filldraw (1,{1*sqrt(3)})circle; \filldraw (3,{1*sqrt(3)})circle;
#   \filldraw (5,{1*sqrt(3)})circle; \filldraw (7,{1*sqrt(3)})circle;
#   \filldraw (9,{1*sqrt(3)})circle; \filldraw (11,{1*sqrt(3)})circle;
#   \filldraw (13,{1*sqrt(3)})circle; \filldraw (15,{1*sqrt(3)})circle;
#   \filldraw (17,{1*sqrt(3)})circle; \filldraw (19,{1*sqrt(3)})circle;
#   \filldraw (0,{2*sqrt(3)})circle; \filldraw (2,{2*sqrt(3)})circle;
#   \filldraw (4,{2*sqrt(3)})circle; \filldraw (6,{2*sqrt(3)})circle;
#   \filldraw (8,{2*sqrt(3)})circle; \filldraw (10,{2*sqrt(3)})circle;
#   \filldraw (12,{2*sqrt(3)})circle; \filldraw (14,{2*sqrt(3)})circle;
#   \filldraw (16,{2*sqrt(3)})circle; \filldraw (18,{2*sqrt(3)})circle;
#   \filldraw (20,{2*sqrt(3)})circle; \filldraw (1,{3*sqrt(3)})circle;
#   \filldraw (3,{3*sqrt(3)})circle; \filldraw (5,{3*sqrt(3)})circle;
#   \filldraw (7,{3*sqrt(3)})circle; \filldraw (9,{3*sqrt(3)})circle;
#   \filldraw (11,{3*sqrt(3)})circle; \filldraw (13,{3*sqrt(3)})circle;
#   \filldraw (15,{3*sqrt(3)})circle; \filldraw (17,{3*sqrt(3)})circle;
#   \filldraw (19,{3*sqrt(3)})circle; \filldraw (0,{4*sqrt(3)})circle;
#   \filldraw (2,{4*sqrt(3)})circle; \filldraw (4,{4*sqrt(3)})circle;
#   \filldraw (6,{4*sqrt(3)})circle; \filldraw (8,{4*sqrt(3)})circle;
#   \filldraw (10,{4*sqrt(3)})circle; \filldraw (12,{4*sqrt(3)})circle;
#   \filldraw (14,{4*sqrt(3)})circle; \filldraw (16,{4*sqrt(3)})circle;
#   \filldraw (18,{4*sqrt(3)})circle; \filldraw (20,{4*sqrt(3)})circle;
#   \filldraw (1,{5*sqrt(3)})circle; \filldraw (3,{5*sqrt(3)})circle;
#   \filldraw (5,{5*sqrt(3)})circle; \filldraw (7,{5*sqrt(3)})circle;
#   \filldraw (9,{5*sqrt(3)})circle; \filldraw (11,{5*sqrt(3)})circle;
#   \filldraw (13,{5*sqrt(3)})circle; \filldraw (15,{5*sqrt(3)})circle;
#   \filldraw (17,{5*sqrt(3)})circle; \filldraw (19,{5*sqrt(3)})circle;
#   \filldraw (0,{6*sqrt(3)})circle; \filldraw (2,{6*sqrt(3)})circle;
#   \filldraw (4,{6*sqrt(3)})circle; \filldraw (6,{6*sqrt(3)})circle;
#   \filldraw (8,{6*sqrt(3)})circle; \filldraw (10,{6*sqrt(3)})circle;
#   \filldraw (12,{6*sqrt(3)})circle; \filldraw (14,{6*sqrt(3)})circle;
#   \filldraw (16,{6*sqrt(3)})circle; \filldraw (18,{6*sqrt(3)})circle;
#   \filldraw (20,{6*sqrt(3)})circle; \filldraw (1,{7*sqrt(3)})circle;
#   \filldraw (3,{7*sqrt(3)})circle; \filldraw (5,{7*sqrt(3)})circle;
#   \filldraw (7,{7*sqrt(3)})circle; \filldraw (9,{7*sqrt(3)})circle;
#   \filldraw (11,{7*sqrt(3)})circle; \filldraw (13,{7*sqrt(3)})circle;
#   \filldraw (15,{7*sqrt(3)})circle; \filldraw (17,{7*sqrt(3)})circle;
#   \filldraw (19,{7*sqrt(3)})circle; \filldraw (0,{8*sqrt(3)})circle;
#   \filldraw (2,{8*sqrt(3)})circle; \filldraw (4,{8*sqrt(3)})circle;
#   \filldraw (6,{8*sqrt(3)})circle; \filldraw (8,{8*sqrt(3)})circle;
#   \filldraw (10,{8*sqrt(3)})circle; \filldraw (12,{8*sqrt(3)})circle;
#   \filldraw (14,{8*sqrt(3)})circle; \filldraw (16,{8*sqrt(3)})circle;
#   \filldraw (18,{8*sqrt(3)})circle; \filldraw (20,{8*sqrt(3)})circle;
#   \filldraw (1,{9*sqrt(3)})circle; \filldraw (3,{9*sqrt(3)})circle;
#   \filldraw (5,{9*sqrt(3)})circle; \filldraw (7,{9*sqrt(3)})circle;
#   \filldraw (9,{9*sqrt(3)})circle; \filldraw (11,{9*sqrt(3)})circle;
#   \filldraw (13,{9*sqrt(3)})circle; \filldraw (15,{9*sqrt(3)})circle;
#   \filldraw (17,{9*sqrt(3)})circle; \filldraw (19,{9*sqrt(3)})circle;
#   % end generated
# 
# \end{tikzpicture}
# \end{center}


